#!/usr/bin/env python3
# -*- mode: python -*-
# -*- coding: utf-8 -*-

"""Exemple utilisation API ScoDoc 9 avec jeton obtenu par basic authentication

utilisation:
    à faire fonctionner en environnment de test (FLASK_ENV=test_api dans le fichier .env)
    pytest tests/api/test_api_logos.py
"""


# XXX TODO
#  Ce test a une logique très différente des autres : A UNIFIER


from tests.api.setup_test_api import API_URL, api_admin_headers, api_headers

from scodoc import app
from tests.unit.config_test_logos import (
    create_super_token,
    create_admin_token,
    create_lambda_token,
    create_logos,
    create_dept,
)


def test_super_access(api_admin_headers):
    """
    Route: /logos
    """
    headers = api_admin_headers
    with app.test_client(api_admin_headers) as client:
        response = client.get(API_URL + "/logos", headers=headers)
        assert response.status_code == 200
        assert response.json is not None


def test_admin_access(api_headers):
    """
    Route: /logos
    """
    headers = api_headers
    with app.test_client() as client:
        response = client.get(API_URL + "/logos", headers=headers)
        assert response.status_code == 401


def test_lambda_access(api_headers):
    """
    Route: /logos
    """
    headers = api_headers
    with app.test_client() as client:
        response = client.get(API_URL + "/logos", headers=headers)
        assert response.status_code == 401


def test_global_logos(api_admin_headers):
    """
    Route:
    """
    headers = api_admin_headers
    with app.test_client() as client:
        response = client.get(API_URL + "/logos", headers=headers)
        assert response.status_code == 200
        assert response.json is not None
        assert (
            len(response.json) == 4
        )  # 4 items in fakelogo context: ['header', 'footer', 'logo_B', 'logo_C']


def test_local_by_id_logos(api_admin_headers):
    """
    Route: /departement/id/1/logos
    """
    headers = api_admin_headers
    with app.test_client() as client:
        response = client.get(API_URL + "/departement/id/1/logos", headers=headers)
        assert response.status_code == 200
        assert response.json is not None
        assert (
            len(response.json) == 2
        )  # 2 items in dept(1, TAPI) fakelogo context: ['logo_A', 'logo_D']


def test_local_by_name_logos(api_admin_headers):
    """
    Route: /departement/TAPI/logos
    """
    headers = api_admin_headers
    with app.test_client() as client:
        response = client.get(API_URL + "/departement/TAPI/logos", headers=headers)
        assert response.status_code == 200
        assert response.json is not None
        assert (
            len(response.json) == 2
        )  # 2 items in dept(1, TAPI) fakelogo context: ['logo_A', 'logo_D']


def test_local_png_by_id_logo(api_admin_headers):
    """
    Route: /departement/id/1/logo/D
    """
    headers = api_admin_headers
    with app.test_client() as client:
        response = client.get(API_URL + "/departement/id/1/logo/D", headers=headers)
        assert response.status_code == 200
        assert response.headers["Content-Type"] == "image/png"
        assert response.headers["Content-Disposition"].startswith("inline")
        assert "logo_D.png" in response.headers["Content-Disposition"]


def test_global_png_logo(api_admin_headers):
    """
    Route: /logo/C
    """
    headers = api_admin_headers
    with app.test_client() as client:
        response = client.get(API_URL + "/logo/C", headers=headers)
        assert response.status_code == 200
        assert response.headers["Content-Type"] == "image/png"
        assert response.headers["Content-Disposition"].startswith("inline")
        assert "logo_C.png" in response.headers["Content-Disposition"]


def test_global_jpg_logo(api_admin_headers):
    """
    Route: /logo/B
    """
    headers = api_admin_headers
    with app.test_client() as client:
        response = client.get(API_URL + "/logo/B", headers=headers)
        assert response.status_code == 200
        assert response.headers["Content-Type"] == "image/jpg"
        assert response.headers["Content-Disposition"].startswith("inline")
        assert "logo_B.jpg" in response.headers["Content-Disposition"]


def test_local_png_by_name_logo(api_admin_headers):
    """
    Route: /departement/TAPI/logo/A
    """
    headers = api_admin_headers
    with app.test_client() as client:
        response = client.get(API_URL + "/departement/TAPI/logo/D", headers=headers)
        assert response.status_code == 200
        assert response.headers["Content-Type"] == "image/png"
        assert response.headers["Content-Disposition"].startswith("inline")
        assert "logo_D.png" in response.headers["Content-Disposition"]


def test_local_jpg_by_id_logo(api_admin_headers):
    """
    Route: /departement/id/1/logo/D
    """
    headers = api_admin_headers
    with app.test_client() as client:
        response = client.get(API_URL + "/departement/id/1/logo/A", headers=headers)
        assert response.status_code == 200
        assert response.headers["Content-Type"] == "image/jpg"
        assert response.headers["Content-Disposition"].startswith("inline")
        assert "logo_A.jpg" in response.headers["Content-Disposition"]


def test_local_jpg_by_name_logo(api_admin_headers):
    """
    Route: /departement/TAPI/logo/A
    """
    headers = api_admin_headers
    with app.test_client() as client:
        response = client.get(API_URL + "/departement/TAPI/logo/A", headers=headers)
        assert response.status_code == 200
        assert response.headers["Content-Type"] == "image/jpg"
        assert response.headers["Content-Disposition"].startswith("inline")
        assert "logo_A.jpg" in response.headers["Content-Disposition"]
